View source: R/output_functions.R
| write_carbon_ambient_data | R Documentation |
Write out ambient observations from the NEON EC towers where the isotope data (either H2O or CO2) have been calibrated using this package.
write_carbon_ambient_data(
outname,
site,
amb_data_list,
to_file = TRUE,
fid = NULL
)
outname |
Output file name. |
site |
NEON 4-letter site code. |
amb_data_list |
Calibrated list of ambient data - this is the output from one of the calibrate_ambient_carbon* functions. |
to_file |
Write to file (TRUE) or to environment (FALSE). |
fid |
Optional open HDF5 file handle. If NULL, the file is opened and closed internally. |
Nothing to the environment, but writes data in amb_data_list to file.
Rich Fiorella rfiorella@lanl.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.